#
# spec file for package sirilic
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sirilic
Version:        1.15.8
Release:        1.4
Summary:        Software that uses SiriL for preparing acquisition files for processing
License:        LGPL-3.0-or-later
URL:            https://gitlab.com/free-astro/sirilic
Source:         https://gitlab.com/free-astro/sirilic/-/archive/V%{version}/sirilic-V%{version}.tar.bz2
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  pkgconfig(python3) >= 3.6
Requires:       siril >= 1.0.6
BuildArch:      noarch
BuildRequires:  python3-wxPython >= 4.0
Requires:       python3-wxPython >= 4.0

%description
SiriLic ( SiriL Image Converter) is a software for preparing
acquisition files (raw, Offset, Flat and Dark) for processing with SiriL software.
It does three things:
* Structuring the SiriL working directory into sub-folders
* Convert Raw, Offset, Dark or Flat files into SiriL sequence
* Automatically generate the SiriL script according to the files present and the options
Sirilic allows also to batch process multiple channel and sessions.

%prep
%setup -q -n %{name}-V%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
sed -i 's/\/usr\/bin\/env python/\/usr\/bin\/python3/g' %{buildroot}/%{python3_sitelib}/%{name}/*.py
sed -i 's/\/usr\/bin\/env python/\/usr\/bin\/python3/g' %{buildroot}/%{python3_sitelib}/%{name}/*.pyw
rm -f %{buildroot}/%{python3_sitelib}/%{name}/i18n/fr_FR/LC_MESSAGES/sirilic.mo

%files
%{_bindir}/sirilic
%{_datadir}/applications/sirilic.desktop
%{_datadir}/pixmaps/sirilic.png
%{python3_sitelib}/*

%changelog
* Mon Oct  9 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.15.8:
  * fix "platesolving"
  * fix "weighing" only for light
  * check if Siril path is a file and file access is "x"
  * fix coords format (Simbad) (Sometimes, the format is not degre minute second)
  * fix project history
* Thu Oct  5 2023 Paolo Stivanin <info@paolostivanin.com>
- Remove useless checks.
* Wed Sep  6 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.15.7:
  * fix: the path to the "About" dialog box icon
  * Menu refactoring
  * add icons in menu
  * add platesolve
  * add request object coords in simbad
  * add 'find text' and 'goto line' to the script editor
* Fri Jul 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.15.3:
  * fix drizzle in duoband (Ha/O3)
  * add a internal script editor
* Mon Jun  5 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.15.2:
  * add an button : 'Edit/Run'
  * fix: option findstar
  * fix: stop siril processing
* Tue Mar 14 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.15.0:
  * add new options for preprocessing
  * add new options for registring
  * add new options for stacking
  * add new options for subsky
  * add new fonction ( seqapplyreg )
  * add L/RGB compositing
  * add a dialog box to load files according to a pattern
  * improvement of the properties tab
  * fix a bug in multi-session ( issue #25 )
  * fix a bug '2pass' ( issue #24 )
* Thu Mar 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.14.3:
  * GUI refactoring
* Tue Jan 11 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.14.2:
  * fix 'norot' register option (no prefix)
  * fix register options with multi-session
  * add register options: -transf, -norot, -minpairs
  * stop the script if there is an empty session
  * add the synthetic bias
  * delete 'hcompress' option for the compression
* Thu Nov  4 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.13.11:
  * fix size spinCtrlDouble
  * update GUI
  * add scroll bars for low res screens
  * add MAD rejection
* Mon Jun 21 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.13.10:
  * fix Issue #13: no debayer with cosme in  Ha or HaO3  filter (DLSR)
  * fix range for "generalized" and "percentile" rejection
  * add ExtractGreen
  * add option "weighted"
  * add option "rejection type"
  * add option "identical parameters for all layers"
  * add a 'Siril' button in the log tab
  * delete flip option
  * fix namepath with a simple quote
  * fix remove_file() with symbolic link on linux when the source file is deleted
  * Correction of the log display when no image is selected
* Thu Apr  8 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.13.6:
  * fix remove_file() with symbolic link
  * add linear_match to Duo Band (HaO3)
  * fix project history
  * fix GetHDU() with compressed FITS
  * Change label CCD => OSC/CCD
  * fix DuoBand HaO3  with subsky option
  * add an abort when the sequence contains an image only
  * fix objectname with space
  * fix the reading of the FITS file header (bitpix < 0 if float32)
  * fix remove_file()
* Tue Mar  2 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.13.1:
  * refactoring for siril 0.99.8
  * add fix fujiX
  * add processing summary
  * add search field in the log tab
  * add subsky sequence
  * add single-multi fit / ser mode
  * add ser processing
  * optimisation code
  * generic script without absolute path
  * fix Sirilic Step by Step (debug)
  * fix reverse project
* Mon Nov 23 2020 Paolo Stivanin <info@paolostivanin.com>
- First release in OBS, v1.12.8
